@@ -259,6 +259,14 @@ class SagemakerFeatureStore:
             feature_definitions=feature_definitions,
         )
 
+        # temporary disable online store
+        if (
+            "dynamodb" not in online_store_sources
+            and enable_online_store
+            and enable_offline_store
+        ):
+            enable_online_store = False
+
         # Feature group creation
         feature_group.create(
             s3_uri=(
@@ -273,6 +281,14 @@ class SagemakerFeatureStore:
         print(f'Creating "{feature_group_name}" Feature Group..')
         self._wait_for_feature_group_creation(feature_group)
 
+        # reenable online
+        if (
+            "dynamodb" not in online_store_sources
+            and enable_online_store
+            and enable_offline_store
+        ):
+            enable_online_store = True
+
         # Store registry in S3 after successful creation to AWS Sagemaker FS
         feature_registry_s3 = f"s3://{self.default_s3_bucket_name}/registry"
 
